@@ -228,11 +228,11 @@ class NotificationBaseEmbed:
 
     @staticmethod
     def _gen_eveentity_external_url(eve_entity: EveEntity) -> str:
-        if eve_entity.category == EveEntity.CATEGORY_ALLIANCE:
+        if eve_entity.category == EveEntity.Category.ALLIANCE:
             return dotlan.alliance_url(eve_entity.name)
-        elif eve_entity.category == EveEntity.CATEGORY_CORPORATION:
+        elif eve_entity.category == EveEntity.Category.CORPORATION:
             return dotlan.corporation_url(eve_entity.name)
-        elif eve_entity.category == EveEntity.CATEGORY_CHARACTER:
+        elif eve_entity.category == EveEntity.Category.CHARACTER:
             return evewho.character_url(eve_entity.id)
 
     @classmethod
