@@ -258,12 +258,10 @@ class Owner(models.Model):
             "esi-corporations.read_structures.v1",
             "esi-universe.read_structures.v1",
             "esi-characters.read_notifications.v1",
+            "esi-assets.read_corporation_assets.v1",
         ]
         if STRUCTURES_FEATURE_CUSTOMS_OFFICES:
-            scopes += [
-                "esi-planets.read_customs_offices.v1",
-                "esi-assets.read_corporation_assets.v1",
-            ]
+            scopes += ["esi-planets.read_customs_offices.v1"]
         if STRUCTURES_FEATURE_STARBASES:
             scopes += ["esi-corporations.read_starbases.v1"]
         return scopes
@@ -517,7 +515,7 @@ class Owner(models.Model):
                         "name": name if name else "",
                         "system_id": poco["system_id"],
                         "reinforce_hour": reinforce_hour.hour,
-                        "state": Structure.STATE_UNKNOWN,
+                        "state": Structure.State.UNKNOWN,
                     }
                     if planet_id:
                         structure["planet_id"] = planet_id
@@ -774,7 +772,7 @@ class Owner(models.Model):
         return success
 
     def _fetch_notifications_from_esi(self, token: Token) -> dict:
-        """ fetching all notifications from ESI for current owner"""
+        """fetching all notifications from ESI for current owner"""
         add_prefix = self._logger_prefix()
         notifications = esi_fetch(
             "Character.get_characters_character_id_notifications",
@@ -833,10 +831,8 @@ class Owner(models.Model):
         # create new notif objects
         new_notification_objects = list()
         for notification in new_notifications:
-            sender_type = EveEntity.get_matching_entity_category(
-                notification["sender_type"]
-            )
-            if sender_type != EveEntity.CATEGORY_OTHER:
+            sender_type = EveEntity.Category.from_esi_name(notification["sender_type"])
+            if sender_type != EveEntity.Category.OTHER:
                 sender, _ = EveEntity.objects.get_or_create_esi(
                     eve_entity_id=notification["sender_id"]
                 )
